==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtregionsegHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ΰڤФ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "ʿ(X)ɸ"
#define HOLC "ʿ(X)ɸ"
#define HOLF NULL

/*-V*/
#define VERT "ľ(Y)ɸ"
#define VERC "ľ(Y)ɸ"
#define VERF NULL

/*-v*/
#define HTFT "positive"
#define HTFC "positive"
#define HTFF NULL

/*-s*/
#define SPFT "total"
#define SPFC "total"
#define SPFF NULL

/*-M*/
#define SPVT "total(οĴ)"
#define SPVC "total(οĴ)"

/*-S*/
#define SIZT "(X,⤵Y)"
#define SIZC "(X,⤵Y)"

/*-c*/
#define RTPT "ΰη"
#define RTPC "ΰη"
#define RTPS "XñĴ,YñĴ,XYñĴ,"

/*-n*/
#define NULT "NULLΰ"
#define NULC "NULLΰ"
#define NULS "PositiveȤƥ,NegativeȤƥ"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "󼡸ޥȥåΰ(XñĴ,YñĴ,XYñĴ,)ڤФ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtregionseg -H X -V Y -v Red -M255 -S 100,100 -r x -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2ppm,ppm2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/en/xtregionsegHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ΰڤФ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "horizontal (x) coordinate"
#define HOLC "horizontal (x) coordinate"
#define HOLF NULL

/*-V*/
#define VERT "vertical (y) coordinate"
#define VERC "vertical (y) coordinate"
#define VERF NULL

/*-v*/
#define HTFT "the number of positive instances for a cell"
#define HTFC "the number of positive instances for a cell"
#define HTFF NULL

/*-s*/
#define SPFT "the number of instances in a cell"
#define SPFC "the number of instances in a cell"
#define SPFF NULL

/*-M*/
#define SPVT "the number of instances (maximum color scale value)"
#define SPVC "the number of instances (maximum color scale value)"

/*-S*/
#define SIZT "size (width X, height Y)"
#define SIZC "size (width X, height Y)"

/*-c*/
#define RTPT "shape of region"
#define RTPC "shape of region"
#define RTPS "x-monotone, y-monotone, xy-monotone, rectangle"

/*-n*/
#define NULT "the way to deal with null value"
#define NULC "the way to deal with null value"
#define NULS "count as positive, count as negative"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "region segmentation (x-monotone, y-monotone, xy-monotone, rectangle) from 2D matrix"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtregionseg -H X -V Y -v Red -M255 -S 100,100 -r x -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2ppm,ppm2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
